launchdarkly_event_source_client library
launchdarkly_sse provides SSE streaming functionality.
Classes
- Event
- Base class for event source events.
- EventSourceLogger
- Simple logging interface for the event source client
- MessageEvent
- Represents a message that came across the SSE stream.
- NoOpLogger
- No-op logger implementation that does nothing
- OpenEvent
- Event emitted when the SSE client connects.
- PrintLogger
- Simple print-based logger for basic logging
- SSECapability
- Optional behaviors that an SSEClient implementation may or may not support. Callers query support with SSEClient.hasCapability and route around missing capabilities (for example, by switching to a query-parameter form of authentication when the transport cannot send custom request headers).
- SSEClient
- An SSEClient that works to maintain a SSE connection to a server.
- TestSseClient
- An SSE client to use for testing.
Enums
- LogLevel
- SseHttpMethod
- HTTP methods supported by the event source client.
Exceptions / Errors
- UnrecoverableStatusError
- Reported on the event stream when the server responds with an HTTP status code that the client will not retry (anything other than 200, 400, 408, 429, or 5xx). After reporting this error the client stops reconnecting until connection desire changes.